==> imuikit-1.0.6.20180130_1T-sources.jar: com/xdja/im/uikit/ui/view/ViewSendImageItem.java <==
package com.xdja.im.uikit.ui.view;

import android.support.annotation.NonNull;
import android.text.TextUtils;
import android.view.View;
import android.widget.ImageView;

import com.bumptech.glide.Glide;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.xdja.im.core.config.ConstDef;
import com.xdja.im.core.model.message.TalkMessageBean;
import com.xdja.im.core.model.message.file.ImageFileInfo;
import com.xdja.im.uikit.R;
import com.xdja.im.uikit.utils.file.FileUtils;
import com.xdja.im.uikit.utils.log.LogUtil;
import com.xdja.im.uikit.view.ChatImageView;

import static com.xdja.im.lib.filemanage.util.HistoryFileUtils.isFileExist;


/**
 * @Package: com.xdja.im.uikit.ui
 * @Author: xdjaxa
 * @Creation: 2017-04-20 14:42
 * @Version V1.0
 * @Description:
 */
public class ViewSendImageItem extends BaseSendItem {

    //private static final int MAX_PLAY_GIF = 3 * 1024 * 1024;

    /**
     * 图片加载显示控件
     */
    private ChatImageView mChatImage;
    /**
     * gif
     */
    private ImageView mGifImageView;
    /**
     * 闪信标识
     */
    private ImageView mBombFlagImg;

    @Override
    protected int getLayoutRes() {
        return R.layout.im_uikit_item_chat_send_image;
    }

    @Override
    protected void injectView() {
        super.injectView();
        mChatImage = (ChatImageView) findViewById(R.id.img_send_image);
        mGifImageView = (ImageView) findViewById(R.id.img_send_gif_image);
        mBombFlagImg = (ImageView) findViewById(R.id.img_bomb_flag);

        mContentLayout.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                getPresenter().previewImage(dataSource);
            }
        });
    }

    @Override
    public void bindDataSource(int position, @NonNull final TalkMessageBean dataSource) {
        super.bindDataSource(position, dataSource);

        ImageFileInfo fileInfo = (ImageFileInfo) dataSource.getFileInfo();
        if (fileInfo == null) {
            LogUtil.e("load image, but file info is null");
            mChatImage.setError(R.mipmap.im_uikit_pic_failed);
            return;
        }

        //加载图片
        loadImage(fileInfo, dataSource);

        //闪信标识
        if (dataSource.isBomb()) {
            mBombFlagImg.setVisibility(View.VISIBLE);
        }
    }

    private void loadImage(ImageFileInfo imageFileInfo, TalkMessageBean dataSource) {
        //本地图片存在
        if (FileUtils.isFileExists(imageFileInfo.getFilePath())) {
            //mChatImage.loadImage(filePath);
            loadImageUrl(imageFileInfo, dataSource);
        } else {
            LogUtil.w("file is not exit.");
            mChatImage.setError(R.mipmap.im_uikit_pic_default);
        }
    }


    /**
     * 加载URL指定图片
     *
     * @param imageFileInfo
     */
    private void loadImageUrl(ImageFileInfo imageFileInfo, TalkMessageBean dataSource) {
        String suffix = imageFileInfo.getSuffix();
        //fix bug 21243 by jyg 20171017
        if (imageFileInfo != null && ConstDef.GIF_TYPE.equalsIgnoreCase(suffix)
                && !TextUtils.isEmpty(imageFileInfo.getFilePath())) {
            String urlGif = imageFileInfo.getFilePath();
            long fileSize = imageFileInfo.getFileSize();
            //fix bug 21243 by jyg 20171017
            mChatImage.setVisibility(View.GONE);
            mGifImageView.setVisibility(View.VISIBLE);
            if (isFileExist(urlGif)) {
//                Glide.with(getActivity()).load(urlGif).diskCacheStrategy(DiskCacheStrategy.SOURCE).into(mGifImageView);
                Glide.with(getActivity()).load(urlGif).placeholder(R.mipmap.im_uikit_pic_default).dontAnimate().override(140,140).diskCacheStrategy(DiskCacheStrategy.SOURCE).into(mGifImageView);
            }
//            mGifImageView.loadImageFrame(urlGif);
//            if (dataSource.isGifPlayed()) {
//                mGifImageView.stopAnimation();
//            } else {
//                if (isFileExist(urlGif) && fileSize < MAX_PLAY_GIF) {
//                    mGifImageView.loadImage(urlGif);
//                }
//            }
        } else {
            mChatImage.setVisibility(View.VISIBLE);
            mGifImageView.setVisibility(View.GONE);
            mChatImage.loadImage(imageFileInfo.getFilePath());
        }
    }

}

==> imuikit-1.0.6.20180206T-sources.jar: com/xdja/im/uikit/ui/view/ViewSendImageItem.java <==
package com.xdja.im.uikit.ui.view;

import android.support.annotation.NonNull;
import android.text.TextUtils;
import android.view.View;
import android.widget.ImageView;

import com.bumptech.glide.Glide;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.xdja.im.core.config.ConstDef;
import com.xdja.im.core.model.message.TalkMessageBean;
import com.xdja.im.core.model.message.file.ImageFileInfo;
import com.xdja.im.uikit.R;
import com.xdja.im.uikit.utils.file.FileUtils;
import com.xdja.im.uikit.utils.log.LogUtil;
import com.xdja.im.uikit.utils.sys.ScreenUtil;
import com.xdja.im.uikit.view.ChatImageView;

import static com.xdja.im.lib.filemanage.util.HistoryFileUtils.isFileExist;


/**
 * @Package: com.xdja.im.uikit.ui
 * @Author: xdjaxa
 * @Creation: 2017-04-20 14:42
 * @Version V1.0
 * @Description:
 */
public class ViewSendImageItem extends BaseSendItem {

    //private static final int MAX_PLAY_GIF = 3 * 1024 * 1024;

    /**
     * 图片加载显示控件
     */
    private ChatImageView mChatImage;
    /**
     * gif
     */
    private ImageView mGifImageView;
    /**
     * 闪信标识
     */
    private ImageView mBombFlagImg;

    @Override
    protected int getLayoutRes() {
        return R.layout.im_uikit_item_chat_send_image;
    }

    @Override
    protected void injectView() {
        super.injectView();
        mChatImage = (ChatImageView) findViewById(R.id.img_send_image);
        mGifImageView = (ImageView) findViewById(R.id.img_send_gif_image);
        mBombFlagImg = (ImageView) findViewById(R.id.img_bomb_flag);

        mContentLayout.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                getPresenter().previewImage(dataSource);
            }
        });
    }

    @Override
    public void bindDataSource(int position, @NonNull final TalkMessageBean dataSource) {
        super.bindDataSource(position, dataSource);

        ImageFileInfo fileInfo = (ImageFileInfo) dataSource.getFileInfo();
        if (fileInfo == null) {
            LogUtil.e("load image, but file info is null");
            mChatImage.setError(R.mipmap.im_uikit_pic_failed);
            return;
        }

        //加载图片
        loadImage(fileInfo, dataSource);

        //闪信标识
        if (dataSource.isBomb()) {
            mBombFlagImg.setVisibility(View.VISIBLE);
        }
    }

    private void loadImage(ImageFileInfo imageFileInfo, TalkMessageBean dataSource) {
        //本地图片存在
        if (FileUtils.isFileExists(imageFileInfo.getFilePath())) {
            //mChatImage.loadImage(filePath);
            loadImageUrl(imageFileInfo, dataSource);
        } else {
            LogUtil.w("file is not exit.");
            mChatImage.setError(R.mipmap.im_uikit_pic_default);
        }
    }


    /**
     * 加载URL指定图片
     *
     * @param imageFileInfo
     */
    private void loadImageUrl(ImageFileInfo imageFileInfo, TalkMessageBean dataSource) {
        String suffix = imageFileInfo.getSuffix();
        //fix bug 21243 by jyg 20171017
        if (imageFileInfo != null && ConstDef.GIF_TYPE.equalsIgnoreCase(suffix)
                && !TextUtils.isEmpty(imageFileInfo.getFilePath())) {
            String urlGif = imageFileInfo.getFilePath();
            long fileSize = imageFileInfo.getFileSize();
            //fix bug 21243 by jyg 20171017
            mChatImage.setVisibility(View.GONE);
            mGifImageView.setVisibility(View.VISIBLE);
            if (isFileExist(urlGif)) {
                Glide.with(getActivity())
                        .load(urlGif)
                        .placeholder(R.mipmap.im_uikit_pic_default)
                        .diskCacheStrategy(DiskCacheStrategy.SOURCE)
                        .into(mGifImageView);
            }
        } else {
            mChatImage.setVisibility(View.VISIBLE);
            mGifImageView.setVisibility(View.GONE);
            mChatImage.loadImage(imageFileInfo.getFilePath());
//            Glide.with(getActivity())
//                    .load(imageFileInfo.getFilePath())
//                    .placeholder(R.mipmap.im_uikit_pic_default)
//                    .diskCacheStrategy(DiskCacheStrategy.SOURCE)
//                    .into(mChatImage);
        }
    }

}
